@@ -34,7 +34,6 @@ import org.apache.cxf.jaxrs.resources.UriBuilderWrongAnnotations;
 import org.apache.cxf.jaxrs.utils.JAXRSUtils;
 
 import org.junit.Assert;
-import org.junit.Ignore;
 import org.junit.Test;
 
 public class UriBuilderImplTest extends Assert {
@@ -153,6 +152,28 @@ public class UriBuilderImplTest extends Assert {
         assertEquals("URI is not built correctly", "http://bar", newUri.toString());
     }
     
+    @Test
+    public void testCloneWithoutLeadingSlash() throws Exception {
+        URI uri = new URI("bar/foo");
+        URI newUri = new UriBuilderImpl(uri).clone().build();   
+        assertEquals("URI is not built correctly", "bar/foo", newUri.toString());
+    }
+    
+    @Test
+    public void testCloneWithLeadingSlash() throws Exception {
+        URI uri = new URI("/bar/foo");
+        URI newUri = new UriBuilderImpl(uri).clone().build();   
+        assertEquals("URI is not built correctly", "/bar/foo", newUri.toString());
+    }
+    
+    @Test
+    public void testBuildWithLeadingSlash() throws Exception {
+        URI uri = new URI("/bar/foo");
+        URI newUri = UriBuilder.fromUri(uri).build();   
+        assertEquals("URI is not built correctly", "/bar/foo", newUri.toString());
+    }
+    
+    
     @Test
     public void testClonePctEncodedFromUri() throws Exception {
         URI uri = new URI("http://bar/foo%20");
@@ -1091,7 +1112,6 @@ public class UriBuilderImplTest extends Assert {
     }
     
     @Test
-    @Ignore("QueryParamTest5")
     public void testEncodingQueryParamFromBuild() throws Exception {
         String expectedValue =
                 "http://localhost:8080?name=x%3D&name=y?&name=x+y&name=%26";
@@ -1101,7 +1121,6 @@ public class UriBuilderImplTest extends Assert {
     }
     
     @Test
-    @Ignore("ReplaceQueryParamTest3")
     public void testReplaceParamAndEncodeQueryParamFromBuild() throws Exception {
         String expectedValue =
                 "http://localhost:8080?name=x&name=y&name=y+x&name=x%25y&name=%20";
@@ -1112,7 +1131,6 @@ public class UriBuilderImplTest extends Assert {
     }
 
     @Test
-    // ReplaceQuery3
     public void testReplaceStringAndEncodeQueryParamFromBuild() {
         String expected = "http://localhost:8080?name1=x&name2=%20&name3=x+y&name4=23&name5=x%20y";
 
