@@ -41,9 +41,6 @@ import org.apache.cxf.message.Exchange;
 import org.apache.cxf.message.Message;
 import org.apache.cxf.message.MessageImpl;
 import org.apache.cxf.service.model.EndpointInfo;
-import org.apache.cxf.transport.Destination;
-import org.apache.cxf.transport.DestinationFactory;
-import org.apache.cxf.transport.DestinationFactoryManager;
 import org.apache.cxf.transport.MessageObserver;
 import org.apache.cxf.ws.addressing.EndpointReferenceType;
 import org.easymock.classextension.EasyMock;
@@ -54,8 +51,6 @@ import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;
 
-import static org.apache.cxf.message.Message.DECOUPLED_CHANNEL_MESSAGE;
-
 /**
  */
 public class HTTPConduitURLEasyMockTest extends Assert {
@@ -91,13 +86,12 @@ public class HTTPConduitURLEasyMockTest extends Assert {
             connectionFactory = testFactory;
         }
         @Override
-        protected void retrieveConnectionFactory() {
-            // do nothing. i.e do not change the connectionFactory field.
-        }
-        protected void retrieveConnectionFactory(String s) {
+        protected HttpURLConnectionFactory retrieveConnectionFactory(String s) {
             // do nothing. i.e do not change the connectionFactory field.
+            return connectionFactory;
         }
         
+        
     }
     /**
      * @throws java.lang.Exception
@@ -127,192 +121,82 @@ public class HTTPConduitURLEasyMockTest extends Assert {
     @Test
     public void testSend() throws Exception {
         control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, false);
+        HTTPConduit conduit = setUpConduit(true, false);
         Message message = new MessageImpl();
         conduit.prepare(message);
-        verifySentMessage(conduit, message);
+        verifySentMessage(conduit, message, "POST");
         finalVerify();
     }
     
     @Test
     public void testSendWithHeaders() throws Exception {
         control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, false);
+        HTTPConduit conduit = setUpConduit(true, false);
         Message message = new MessageImpl();
         message.put("Content-Type", "text/xml;charset=utf8");
         setUpHeaders(message);
         conduit.prepare(message);
-        verifySentMessage(conduit, message, true);
+        verifySentMessage(conduit, message, true, "POST");
         finalVerify();
     }
     
     @Test
     public void testSendHttpConnection() throws Exception {
         control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, false);
+        HTTPConduit conduit = setUpConduit(true, false);
         Message message = new MessageImpl();
         conduit.prepare(message);
-        verifySentMessage(conduit, message);
+        verifySentMessage(conduit, message, "POST");
         finalVerify();
     }
 
     @Test
     public void testSendHttpConnectionAutoRedirect() throws Exception {
         control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, true, false);
+        HTTPConduit conduit = setUpConduit(true, true);
         Message message = new MessageImpl();
         conduit.prepare(message);
-        verifySentMessage(conduit, message);
+        verifySentMessage(conduit, message, "POST");
         finalVerify();
     }
 
     @Test
-    public void testSendOnewayExplicitLenghtPartialResponse()
-        throws Exception {
+    public void testSendHttpGetConnectionAutoRedirect() throws Exception {
         control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);        
+        HTTPConduit conduit = setUpConduit(true, true, "GET");
         Message message = new MessageImpl();
+        message.put(Message.HTTP_REQUEST_METHOD, "GET");
         conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.NONE,
-                          ResponseDelimiter.LENGTH,
-                          false); // non-empty response
+        verifySentMessage(conduit, message, "GET");
+        conduit.close(message);
         finalVerify();
     }
-        
+
     @Test
-    public void testSendOnewayChunkedPartialResponse() 
-        throws Exception {
+    public void testSendHttpGetConnection() throws Exception {
         control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
+        HTTPConduit conduit = setUpConduit(true, false, "GET");
         Message message = new MessageImpl();
+        message.put(Message.HTTP_REQUEST_METHOD, "GET");
         conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.NONE,
-                          ResponseDelimiter.CHUNKED,
-                          false); // non-empty response
+        verifySentMessage(conduit, message, "GET");
+        conduit.close(message);
         finalVerify();
     }
-    
+
     @Test
     public void testSendOnewayChunkedEmptyPartialResponse() 
         throws Exception {
         control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
+        HTTPConduit conduit = setUpConduit(true, false);
         Message message = new MessageImpl();
         conduit.prepare(message);
         verifySentMessage(conduit, 
                           message, 
                           ResponseStyle.NONE,
                           ResponseDelimiter.CHUNKED,
-                          true);  // empty response
-        finalVerify();
-    }
-
-    @Test
-    public void testSendOnewayEOFTerminatedPartialResponse() 
-        throws Exception {
-        control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
-        Message message = new MessageImpl();
-        conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.NONE,
-                          ResponseDelimiter.EOF,
-                          false); // non-empty response
-        finalVerify();
-    }
-    
-    @Test
-    public void testSendOnewayEOFTerminatedEmptyPartialResponse() 
-        throws Exception {
-        control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
-        Message message = new MessageImpl();
-        conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.NONE,
-                          ResponseDelimiter.EOF,
-                          true); // empty response
-        finalVerify();
-    }
-    
-    @Test
-    public void testSendDecoupledExplicitLenghtPartialResponse()
-        throws Exception {
-        control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
-        Message message = new MessageImpl();
-        conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.DECOUPLED,
-                          ResponseDelimiter.LENGTH,
-                          false); // non-empty response
-        finalVerify();
-    }
-
-    @Test
-    public void testSendDecoupledChunkedPartialResponse() 
-        throws Exception {
-        control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
-        Message message = new MessageImpl();
-        conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.DECOUPLED,
-                          ResponseDelimiter.CHUNKED,
-                          false); // non-empty response
-        finalVerify();
-    }
-    
-    @Test
-    public void testSendDecoupledChunkedEmptyPartialResponse() 
-        throws Exception {
-        control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
-        Message message = new MessageImpl();
-        conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.DECOUPLED,
-                          ResponseDelimiter.CHUNKED,
-                          true);  // empty response
-        finalVerify();
-    }
-
-    @Test
-    public void testSendDecoupledEOFTerminatedPartialResponse() 
-        throws Exception {
-        control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
-        Message message = new MessageImpl();
-        conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.DECOUPLED,
-                          ResponseDelimiter.EOF,
-                          false); // non-empty response
-        finalVerify();
-    }
-    
-    @Test
-    public void testSendDecoupledEOFTerminatedEmptyPartialResponse() 
-        throws Exception {
-        control = EasyMock.createNiceControl();
-        HTTPConduit conduit = setUpConduit(true, false, true);
-        Message message = new MessageImpl();
-        conduit.prepare(message);
-        verifySentMessage(conduit, 
-                          message, 
-                          ResponseStyle.DECOUPLED,
-                          ResponseDelimiter.EOF,
-                          true); // empty response
+                          true,  // empty response
+                          "POST");
         finalVerify();
     }
     
@@ -343,11 +227,15 @@ public class HTTPConduitURLEasyMockTest extends Assert {
         exchange.isSynchronous();
         EasyMock.expectLastCall().andReturn(true);
     }
+    
+    private HTTPConduit setUpConduit(boolean send, boolean autoRedirect) throws Exception {
+        return setUpConduit(send, autoRedirect, "POST");
+    }
 
     private HTTPConduit setUpConduit(
         boolean send,
         boolean autoRedirect,
-        boolean decoupled
+        String method
     ) throws Exception {
         endpointInfo = new EndpointInfo();
         endpointInfo.setAddress(NOWHERE + "bar/foo");
@@ -367,18 +255,18 @@ public class HTTPConduitURLEasyMockTest extends Assert {
             connection.setDoOutput(true);
             EasyMock.expectLastCall();
             
-            connection.setRequestMethod("POST");
+            connection.setRequestMethod(method);
             EasyMock.expectLastCall();
-            
-            if (!autoRedirect) {
-                connection.getRequestMethod();
-                EasyMock.expectLastCall().andReturn("POST");
+
+            if (!autoRedirect && "POST".equals(method)) {
                 connection.setChunkedStreamingMode(-1);
-                EasyMock.expectLastCall();                    
-            } else {
-                connection.getRequestMethod();
-                EasyMock.expectLastCall().andReturn("POST").anyTimes();
+                EasyMock.expectLastCall();
             }
+            connection.getRequestMethod();
+            EasyMock.expectLastCall().andReturn(method).anyTimes();
+            
+            connection.setInstanceFollowRedirects(false);
+            EasyMock.expectLastCall().times(1);
 
             connection.setConnectTimeout(303030);
             EasyMock.expectLastCall();
@@ -390,23 +278,6 @@ public class HTTPConduitURLEasyMockTest extends Assert {
         }
 
         CXFBusImpl bus = new CXFBusImpl();
-        URL decoupledURL = null;
-        if (decoupled) {
-            decoupledURL = new URL(NOWHERE + "response");
-            DestinationFactoryManager mgr =
-                control.createMock(DestinationFactoryManager.class);
-            DestinationFactory factory =
-                control.createMock(DestinationFactory.class);
-            Destination destination =
-                control.createMock(Destination.class);
-
-            bus.setExtension(mgr, DestinationFactoryManager.class);
-            mgr.getDestinationFactoryForUri(decoupledURL.toString());
-            EasyMock.expectLastCall().andReturn(factory);
-            factory.getDestination(EasyMock.isA(EndpointInfo.class));
-            EasyMock.expectLastCall().andReturn(destination);
-            destination.setMessageObserver(EasyMock.isA(HTTPConduit.InterposedMessageObserver.class));
-        }
         
         control.replay();
         
@@ -426,13 +297,6 @@ public class HTTPConduitURLEasyMockTest extends Assert {
             }
         }
 
-        if (decoupled) {
-            conduit.getClient().setDecoupledEndpoint(decoupledURL.toString());
-            assertNotNull("expected back channel", conduit.getBackChannel());
-        } else {
-            assertNull("unexpected back channel", conduit.getBackChannel());
-        }
-
         observer = new MessageObserver() {
             public void onMessage(Message m) {
                 inMessage = m;
@@ -441,48 +305,53 @@ public class HTTPConduitURLEasyMockTest extends Assert {
         conduit.setMessageObserver(observer);
         return conduit;
     }
-    
 
-    private void verifySentMessage(HTTPConduit conduit, Message message)
+    private void verifySentMessage(HTTPConduit conduit, Message message, String method)
         throws IOException {
-        verifySentMessage(conduit, message, false);
-    }
-
-    private void verifySentMessage(HTTPConduit conduit,
-                                   Message message,
-                                   boolean expectHeaders)
-        throws IOException {
-        verifySentMessage(conduit,
-                          message,
-                          expectHeaders, 
-                          ResponseStyle.BACK_CHANNEL);
+        verifySentMessage(conduit, message, false, method);
     }
 
     private void verifySentMessage(HTTPConduit conduit,
                                    Message message,
                                    boolean expectHeaders,
-                                   ResponseStyle style)
+                                   String method)
+        throws IOException {
+        verifySentMessage(conduit,
+                          message,
+                          expectHeaders, 
+                          ResponseStyle.BACK_CHANNEL,
+                          method);
+    }
+
+    private void verifySentMessage(HTTPConduit conduit,
+                                   Message message,
+                                   boolean expectHeaders,
+                                   ResponseStyle style,
+                                   String method)
         throws IOException {
         verifySentMessage(conduit,
                           message,
                           expectHeaders,
                           style,
                           ResponseDelimiter.LENGTH,
-                          false);
+                          false,
+                          method);
     }
     
     private void verifySentMessage(HTTPConduit conduit,
                                    Message message,
                                    ResponseStyle style,
                                    ResponseDelimiter delimiter,
-                                   boolean emptyResponse)
+                                   boolean emptyResponse,
+                                   String method)
         throws IOException {
         verifySentMessage(conduit,
                           message,
                           false,
                           style,
                           delimiter,
-                          emptyResponse);
+                          emptyResponse,
+                          method);
     }
 
     private void verifySentMessage(HTTPConduit conduit,
@@ -490,28 +359,33 @@ public class HTTPConduitURLEasyMockTest extends Assert {
                                    boolean expectHeaders,
                                    ResponseStyle style,
                                    ResponseDelimiter delimiter,
-                                   boolean emptyResponse)
+                                   boolean emptyResponse,
+                                   String method)
         throws IOException {
         control.verify();
         control.reset();
 
-        OutputStream wrappedOS = verifyRequestHeaders(message, expectHeaders);
+        OutputStream wrappedOS = verifyRequestHeaders(message, expectHeaders, method);
 
-        os.write(PAYLOAD.getBytes(), 0, PAYLOAD.length());
-        EasyMock.expectLastCall();
-        
-        os.flush();
-        EasyMock.expectLastCall();
-        os.flush();
-        EasyMock.expectLastCall();
-        os.close();
-        EasyMock.expectLastCall();
+        if (!"GET".equals(method)) {
+            os.write(PAYLOAD.getBytes(), 0, PAYLOAD.length());
+            EasyMock.expectLastCall();
+            
+            os.flush();
+            EasyMock.expectLastCall();
+            os.flush();
+            EasyMock.expectLastCall();
+            os.close();
+            EasyMock.expectLastCall();
+        }
         
         if (style == ResponseStyle.NONE) {
             setUpOneway(message);
         }
         
-        verifyHandleResponse(style, delimiter);
+        connection.getRequestMethod();
+        EasyMock.expectLastCall().andReturn(method).anyTimes();
+        verifyHandleResponse(style, delimiter, conduit);
 
         control.replay();
         
@@ -537,16 +411,10 @@ public class HTTPConduitURLEasyMockTest extends Assert {
             }
         }
         
-        if (style == ResponseStyle.DECOUPLED) {
-            verifyDecoupledResponse(conduit);
-        }
-        
-        conduit.close();
-        
         finalVerify();
     }
 
-    private OutputStream verifyRequestHeaders(Message message, boolean expectHeaders)
+    private OutputStream verifyRequestHeaders(Message message, boolean expectHeaders, String method)
         throws IOException {
         Map<String, List<String>> headers =
             CastUtils.cast((Map<?, ?>)message.get(Message.PROTOCOL_HEADERS));
@@ -555,11 +423,13 @@ public class HTTPConduitURLEasyMockTest extends Assert {
                    message.getContentFormats().contains(OutputStream.class));
         
         connection.getRequestMethod();
-        EasyMock.expectLastCall().andReturn("POST").anyTimes();
+        EasyMock.expectLastCall().andReturn(method).anyTimes();
 
-        os = EasyMock.createMock(OutputStream.class);
-        connection.getOutputStream();
-        EasyMock.expectLastCall().andReturn(os);
+        if (!"GET".equals(method)) {
+            os = EasyMock.createMock(OutputStream.class);
+            connection.getOutputStream();
+            EasyMock.expectLastCall().andReturn(os);
+        }
         
         message.put(HTTPConduit.KEY_HTTP_CONNECTION, connection);
         if (expectHeaders) {
@@ -591,21 +461,29 @@ public class HTTPConduitURLEasyMockTest extends Assert {
         return wrappedOS;
     }
     
-    private void verifyHandleResponse(ResponseStyle style, ResponseDelimiter delimiter) 
+    private void verifyHandleResponse(ResponseStyle style, ResponseDelimiter delimiter, HTTPConduit conduit) 
         throws IOException {
-        verifyHandleResponse(style, delimiter, false);
+        verifyHandleResponse(style, delimiter, false, conduit);
     }
     
     private void verifyHandleResponse(ResponseStyle style, 
                                       ResponseDelimiter delimiter,
-                                      boolean emptyResponse) throws IOException {
+                                      boolean emptyResponse,
+                                      HTTPConduit conduit) throws IOException {
         connection.getHeaderFields();
         EasyMock.expectLastCall().andReturn(Collections.EMPTY_MAP).anyTimes();
         int responseCode = style == ResponseStyle.BACK_CHANNEL
                            ? HttpURLConnection.HTTP_OK
                            : HttpURLConnection.HTTP_ACCEPTED;
-        connection.getResponseCode();
-        EasyMock.expectLastCall().andReturn(responseCode).anyTimes();
+        if (conduit.getClient().isAutoRedirect()) {
+            connection.getResponseCode();
+            EasyMock.expectLastCall().andReturn(301).once().andReturn(responseCode).anyTimes();
+            connection.getURL();
+            EasyMock.expectLastCall().andReturn(new URL(NOWHERE + "bar/foo/redirect")).once();
+        } else {
+            connection.getResponseCode();
+            EasyMock.expectLastCall().andReturn(responseCode).anyTimes();
+        }
         is = EasyMock.createMock(InputStream.class);
         connection.getInputStream();
         EasyMock.expectLastCall().andReturn(is).anyTimes();
@@ -644,30 +522,6 @@ public class HTTPConduitURLEasyMockTest extends Assert {
         }
     }
     
-    private void verifyDecoupledResponse(HTTPConduit conduit)
-        throws IOException {
-        Message incoming = new MessageImpl();
-        conduit.getDecoupledObserver().onMessage(incoming);
-        assertSame("expected pass thru onMessage() notification",
-                   inMessage,
-                   incoming);
-        assertEquals("unexpected response code",
-                     HttpURLConnection.HTTP_OK,
-                     inMessage.get(Message.RESPONSE_CODE));
-        assertEquals("expected DECOUPLED_CHANNEL_MESSAGE flag set",
-                     Boolean.TRUE,
-                     inMessage.get(DECOUPLED_CHANNEL_MESSAGE));
-        assertEquals("unexpected HTTP_REQUEST set",
-                     false,
-                     inMessage.containsKey(AbstractHTTPDestination.HTTP_REQUEST));
-        assertEquals("unexpected HTTP_RESPONSE set",
-                     false,
-                     inMessage.containsKey(AbstractHTTPDestination.HTTP_RESPONSE));
-        assertEquals("unexpected Message.ASYNC_POST_RESPONSE_DISPATCH set",
-                     false,
-                     inMessage.containsKey(Message.ASYNC_POST_RESPONSE_DISPATCH));
-    }
-
     private void finalVerify() {
         if (control != null) {
             control.verify();
