@@ -19,15 +19,12 @@
 
 package org.apache.cxf.transport.jms;
 
-import java.io.ByteArrayInputStream;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.OutputStream;
 import java.io.UnsupportedEncodingException;
 import java.util.Calendar;
 import java.util.Collection;
 import java.util.GregorianCalendar;
-import java.util.List;
 import java.util.Map;
 import java.util.SimpleTimeZone;
 import java.util.TimeZone;
@@ -48,7 +45,6 @@ import org.apache.cxf.common.logging.LogUtils;
 import org.apache.cxf.common.util.StringUtils;
 import org.apache.cxf.continuations.ContinuationProvider;
 import org.apache.cxf.continuations.SuspendedInvocationException;
-import org.apache.cxf.helpers.CastUtils;
 import org.apache.cxf.interceptor.OneWayProcessorInterceptor;
 import org.apache.cxf.message.Exchange;
 import org.apache.cxf.message.Message;
@@ -63,6 +59,7 @@ import org.apache.cxf.transport.jms.continuations.JMSContinuationProvider;
 import org.apache.cxf.ws.addressing.EndpointReferenceType;
 import org.apache.cxf.wsdl.EndpointReferenceUtils;
 import org.springframework.jms.connection.JmsResourceHolder;
+import org.springframework.jms.connection.SingleConnectionFactory;
 import org.springframework.jms.core.JmsTemplate;
 import org.springframework.jms.core.MessageCreator;
 import org.springframework.jms.core.SessionCallback;
@@ -113,12 +110,18 @@ public class JMSDestination extends AbstractMultiplexDestination
             new org.apache.cxf.common.i18n.Message("INSUFFICIENT_CONFIGURATION_DESTINATION", LOG, name);
         jmsConfig.ensureProperlyConfigured(msg);
         jmsListener = JMSFactory.createJmsListener(ei, jmsConfig, this, 
-                                                   jmsConfig.getTargetDestination(), null, false);
+                                                   jmsConfig.getTargetDestination());
     }
 
     public void deactivate() {
         if (jmsListener != null) {
             jmsListener.shutdown();
+            // CXF-2788: SingleConnectionFactory ignores the call to
+            // javax.jms.Connection#close(),
+            // use this to really close the target connection.
+            if (jmsListener.getConnectionFactory() instanceof SingleConnectionFactory) {
+                ((SingleConnectionFactory)jmsListener.getConnectionFactory()).destroy();
+            }
         }
     }
 
@@ -127,6 +130,7 @@ public class JMSDestination extends AbstractMultiplexDestination
         this.deactivate();
     }
 
+    @SuppressWarnings("unchecked")
     private Destination resolveDestinationName(final JmsTemplate jmsTemplate, final String name) {
         SessionCallback sc = new SessionCallback() {
             public Object doInJms(Session session) throws JMSException {
@@ -183,16 +187,14 @@ public class JMSDestination extends AbstractMultiplexDestination
         try {
             getLogger().log(Level.FINE, "server received request: ", message);
              // Build CXF message from JMS message
-            MessageImpl inMessage = new MessageImpl();            
+            Message inMessage = new MessageImpl();            
             JMSUtils.populateIncomingContext(message, inMessage, 
                                              JMSConstants.JMS_SERVER_REQUEST_HEADERS, jmsConfig);
             
-            byte[] request = JMSUtils.retrievePayload(message, (String)inMessage.get(Message.ENCODING));
-            getLogger().log(Level.FINE, "The Request Message is [ " + request + "]");
-            inMessage.setContent(InputStream.class, new ByteArrayInputStream(request));
+            JMSUtils.retrieveAndSetPayload(inMessage, message, (String)inMessage.get(Message.ENCODING));
             inMessage.put(JMSConstants.JMS_SERVER_RESPONSE_HEADERS, new JMSMessageHeadersType());
             inMessage.put(JMSConstants.JMS_REQUEST_MESSAGE, message);
-            inMessage.setDestination(this);
+            ((MessageImpl)inMessage).setDestination(this);
             if (jmsConfig.getMaxSuspendedContinuations() != 0) {
                 inMessage.put(ContinuationProvider.class.getName(), 
                               new JMSContinuationProvider(bus,
@@ -217,6 +219,10 @@ public class JMSDestination extends AbstractMultiplexDestination
             // handle the incoming message
             incomingObserver.onMessage(inMessage);
             
+            if (inMessage.getExchange() != null 
+                && inMessage.getExchange().getInMessage() != null) {
+                inMessage = inMessage.getExchange().getInMessage();
+            }
             //need to propagate any exceptions back to Spring container 
             //so transactions can occur
             if (inMessage.getContent(Exception.class) != null && session != null) {
@@ -265,11 +271,12 @@ public class JMSDestination extends AbstractMultiplexDestination
             return;
         }
         try {
-            final JMSMessageHeadersType headers = (JMSMessageHeadersType)outMessage
+            final JMSMessageHeadersType messageProperties = (JMSMessageHeadersType)outMessage
                 .get(JMSConstants.JMS_SERVER_RESPONSE_HEADERS);
-            JMSMessageHeadersType inHeaders = (JMSMessageHeadersType)inMessage
+            JMSMessageHeadersType inMessageProperties = (JMSMessageHeadersType)inMessage
                 .get(JMSConstants.JMS_SERVER_REQUEST_HEADERS);
-            JmsTemplate jmsTemplate = JMSFactory.createJmsTemplate(jmsConfig, inHeaders);
+            JMSUtils.initResponseMessageProperties(messageProperties, inMessageProperties);
+            JmsTemplate jmsTemplate = JMSFactory.createJmsTemplate(jmsConfig, messageProperties);
 
             // setup the reply message
             final javax.jms.Message request = (javax.jms.Message)inMessage
@@ -303,12 +310,8 @@ public class JMSDestination extends AbstractMultiplexDestination
 
                     reply.setJMSCorrelationID(determineCorrelationID(request));
 
-                    JMSUtils.setMessageProperties(headers, reply);
-                    // ensure that the contentType is set to the out jms message header
-                    JMSUtils.addContentTypeToProtocolHeader(outMessage);
-                    Map<String, List<String>> protHeaders = CastUtils.cast((Map<?, ?>)outMessage
-                        .get(Message.PROTOCOL_HEADERS));
-                    JMSUtils.addProtocolHeaders(reply, protHeaders);
+                    JMSUtils.prepareJMSProperties(messageProperties, outMessage, jmsConfig);
+                    JMSUtils.setJMSProperties(reply, messageProperties);
 
                     LOG.log(Level.FINE, "server sending reply: ", reply);
                     return reply;
