@@ -45,6 +45,7 @@ import org.apache.commons.httpclient.methods.PostMethod;
 import org.apache.commons.httpclient.methods.RequestEntity;
 import org.apache.cxf.helpers.IOUtils;
 import org.apache.cxf.io.CachedOutputStream;
+import org.apache.cxf.jaxrs.client.JAXRSClientFactory;
 import org.apache.cxf.jaxrs.client.JAXRSClientFactoryBean;
 import org.apache.cxf.jaxrs.client.WebClient;
 import org.apache.cxf.jaxrs.ext.multipart.Attachment;
@@ -252,6 +253,34 @@ public class JAXRSMultipartTest extends AbstractBusClientServerTestBase {
         assertEquals("CXF in Action - 2", book.getName());
     }
     
+    @Test
+    public void testAddCollectionOfBooksWithProxy() {
+        doTestAddCollectionOfBooksWithProxy(true);
+    }
+    
+    @Test
+    public void testAddCollectionOfBooksWithProxyWithoutHeader() {
+        doTestAddCollectionOfBooksWithProxy(false);
+    }
+    
+    public void doTestAddCollectionOfBooksWithProxy(boolean addHeader) {
+        String address = "http://localhost:" + PORT;
+        MultipartStore client = JAXRSClientFactory.create(address, MultipartStore.class);
+        
+        if (addHeader) {
+            WebClient.client(client).header("Content-Type", "multipart/mixed;type=application/xml");
+        }
+        
+        List<Book> books = new ArrayList<Book>();
+        books.add(new Book("CXF 1", 1L));
+        books.add(new Book("CXF 2", 2L));
+        List<Book> books2 = addHeader ? client.addBooks(books) : client.addBooksWithoutHeader(books);
+        assertNotSame(books, books2);
+        assertEquals(2, books2.size());
+        assertEquals(books.get(0).getId(), books2.get(0).getId());
+        assertEquals(books.get(1).getId(), books2.get(1).getId());
+    }
+    
     @Test
     public void testXopWebClient() throws Exception {
         String address = "http://localhost:" + PORT + "/bookstore/xop";
